clear
set more off
set matsize 800
set mem 500m

*******************************************
*
* This .do file creates the analysis reported in "Assessing the Stability of Psychological and Political Survey Measures"
* American Politics Research
* Alan Gerber, Gregory Huber, David Doherty, Conor Dowling
*
* This version: March 28, 2012
*
*******************************************clear

local localpath=""

use "`localpath'sourcedata\YALECCES2010_PsychStability.dta", clear

****************************
*
* RECODE VARIABLES
*
****************************
destring v276, gen(district)
replace district=1 if district==0
rename v206 state

gen weight=v102

** DEMOGRAPHICS
tab state, gen(state_)
* drop CA indicator
drop state_5

*Race
tab v211, gen(race)
gen r_white=race1
gen r_black=race2
gen r_hispanic=race3
gen r_otherrace=race4+race5+race6+race7+race8
label var r_white "Race: White (1=yes)"
label var r_black "Race: Black (1=yes)"
label var r_hispanic "Race: Hispanic (1=yes)"
label var r_otherrace "Race: Other Race (1=yes)"

*Gender
gen gender=v208-1
label var gender "Female (1=yes)"

*Age
gen age=2010-v207
gen age2=(age^2)/100
label var age "Age (Years)"
label var age2 "Age-squared/100"

*Family Income
gen income=v246
replace income=15 if income>15
gen incomemis = (income>14)
label var incomemis "Income Missing"
label var income "Income (1=<10k; 14=>150k; 15=RF/Skipped)"

*Education
gen educ=v213
label var educ "Education (1=No HS; 6=Post-grad)"
tab educ, gen(educD)
drop educD2
label var educD1 "Education: No HS"
label var educD3 "Education: Some college"
label var educD4 "Education: 2-year college"
label var educD5 "Education: 4-year college"
label var educD6 "Education: Post-graduate"

* Marital Status
gen married=(v214==1)|(v214==6)
label var married "Married/Domestic Partnership (1=yes)"

*Religious Attendance
recode v217 (1=6) (2=5) (3=4) (4=3) (5=2) (6=1) (*=.), gen(religatt)
label var religatt "Religious Attendance (1-6)"

*PID
tab v212a, gen(PID_D)
rename PID_D1 pid_democrat
rename PID_D2 pid_republican
label var pid_democrat "Democrat (1=yes)"
label var pid_republican "Republican (1=yes)"
recode v212d (1=3) (2=2) (3=1) (4 8=0) (5=-1) (6=-2) (7=-3) (*=.), gen(pid7)
label var pid7 "Party ID (-3=Str. Rep.; 3=Str. Dem.)"
recode v212d (1 2 3=1) (4 8=0) (5 6 7=-1)(*=.), gen(pid3_leanpart)
recode v212d (1 2=1) (3 4 5 8=0) (6 7=-1)(*=.), gen(pid3_leanind)
label var pid3_leanpart "3-point Party ID (-1=Rep.; 1=Dem.; leaners as partisans)"
label var pid3_leanind "3-point Party ID (-1=Rep.; 1=Dem.; leaners as independent)"

tab pid3_leanpart, gen(part_D)
rename part_D1 pid_republican_wlean
rename part_D3 pid_democrat_wlean
label var pid_democrat_wlean "Democrat (1=yes; leaners as partisans)"
label var pid_republican_wlean "Republican (1=yes; leaners as partisans)"


*Strength of PID
gen pidstr7=abs(pid7)
label var pidstr7 "Strength PID (0=Indep/not sure, 3=Str. ID)"

*Ideology
recode cc334a (1=3) (2=2) (3=1) (4 8=0) (5=-1) (6=-2) (7=-3) (*=.), gen(ideol)
label var ideol "Ideology (-3=very cons.; 0=moderate/not sure; +3=very lib.)"

*Str. Ideology
gen ideolstr=abs(ideol)
label var ideolstr "Str. Ideology (0=moderate/not sure; +2=str. ideol)"

*Interest in Politics
recode v244 (1=4) (2=3) (3=2) (4 5 6=1) (*=.), gen(interest)
label var interest "Interest in News & Public Affairs (1-4) [DK/Skipped/Hardly at all=1]"

*2008 Turnout
recode cc316 (1 2 3=0) (4=1) (*=.), gen(turnout08)
label var turnout08 "Voted in 2008 (1=yes)"

*2008 Vote Choice
recode cc317 (1=1) (2=-1) (3 5=0) (*=.), gen(presvote08)
label var presvote08 "Pres. Vote Choice in 2008 (-1=McCain; 0=Someone else/don't recall; 1=Obama)"

*2010 Turnout
recode cc401 (1 2 3 4=0) (5=1) (*=.), gen(turnout10)
label var turnout10 "Voted in 2010 (1=yes)"

***********************
** PSYCH MEASURES *****
***********************
foreach i in " " "_post "{
**TIPI
recode yalpsy001`i' yalpsy002`i' yalpsy003`i' yalpsy004`i' yalpsy005`i' yalpsy006`i' yalpsy007`i' yalpsy008`i' yalpsy009`i' yalpsy010`i' (1=1) (2=2) (3=3) (4=4) (5=5) (6=6) (7=7) (*=.), gen(_b_p_extraverted`i' _b_p_critical`i' _b_p_dependable`i' _b_p_anxious`i' _b_p_open`i' _b_p_reserved`i' _b_p_sympathetic`i' _b_p_disorganized`i' _b_p_calm`i' _b_p_conventional`i')
*reverse code
recode _b_p_disorganized`i' _b_p_conventional`i' _b_p_critical`i' _b_p_anxious`i' _b_p_reserved`i' (7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7) (*=.), gen(_b_p_disorganized_R`i' _b_p_conventional_R`i' _b_p_critical_R`i' _b_p_anxious_R`i' _b_p_reserved_R`i')

*Items range from 0 to 1 -- higher values indicate more of the trait
*Big Five - conscientiousness
gen BF_conscientiousness`i' = (((_b_p_dependable`i' + _b_p_disorganized_R`i')/2)-1)/6 
label var BF_conscientiousness`i' "Conscientiousness (0-1)"

*Big Five - openness to experiences
gen BF_openness`i' = (((_b_p_open`i' + _b_p_conventional_R`i')/2)-1)/6
label var BF_openness`i' "Openness (0-1)"

*Big Five - agreeableness
gen BF_agreeableness`i' = (((_b_p_sympathetic`i' + _b_p_critical_R`i')/2)-1)/6
label var BF_agreeableness`i' "Agreeableness (0-1)"

*Big Five - emotional stability
gen BF_stability`i' = (((_b_p_calm`i' + _b_p_anxious_R`i')/2)-1)/6
label var BF_stability`i' "Stability (0-1)"

*Big Five - extraversion
gen BF_extraversion`i' = (((_b_p_extraverted`i' + _b_p_reserved_R`i')/2)-1)/6
label var BF_extraversion`i' "Extraversion (0-1)"

recode yalpsy021`i' yalpsy023`i' (1=0) (2=1) (*=.), gen(rwa1`i' rwa2`i')
recode yalpsy022`i' (1=1) (2=0) (*=.), gen(rwa3`i')
gen rwa`i'=(rwa1`i'+rwa2`i'+rwa3`i')/3
label var rwa`i' "Right Wing Authoritianism (RWA; 0-1)"

* Needs to... 
recode yalpsy031`i' (1=3) (2=2) (3=1) (4=0) (*=.), gen(nte1`i')
recode yalpsy032`i' (1=0) (2=.5) (3=1) (*=.), gen(nte2`i')
recode yalpsy041`i' (1=1) (2=0) (3=.5) (*=.), gen(nfc1`i')
recode yalpsy042`i' (1=0) (2=1) (*=.), gen(nfc2`i')

replace nte1`i'=nte1`i'/3
gen nte`i'=(nte1`i'+nte2`i')/2
gen nfc`i'=(nfc1`i'+nfc2`i')/2
label var nte`i' "Need to Evaluate (0-1)"
label var nfc`i' "Need for Cognition (0-1)"
}

foreach i in  BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion rwa nfc nte{
local label : variable label `i'
gen `i'_change=`i'_post-`i'
label var `i'_post "`label' (Post-Election)"
local label=subinstr("`label'"," (0-1)","",.)
label var `i'_change "Change in `label'"
}

******************************
**Trust/Excitement Questions**
******************************
*Happiness
recode yal301 (1=3) (2=2) (3=1) (4=0) (*=.), gen(happy)
label var happy "Happiness (0=not at all happy; 3=very happy)"
recode yal445 (1=3) (2=2) (3=1) (4=0) (*=.), gen(happy_post)
label var happy_post "Happiness (Post-Election) (0=not at all happy; 3=very happy)"
gen happy_change = happy_post-happy
label var happy_change "Change in Happiness (-=less happy; 0=no change; +=more happy)"

*Discuss politics
recode yal302 (1=0) (2=1) (3=2) (4=3) (5=4) (6=5) (7=6) (8=7) (*=.), gen(talkpol)
label var talkpol "Days in next week talk politics (0-7)"
recode yal446 (1=0) (2=1) (3=2) (4=3) (5=4) (6=5) (7=6) (8=7) (*=.), gen(talkpol_post)
label var talkpol_post "Days in next week talk politics (Post-Election) (0-7)"
gen talkpol_change = talkpol_post-talkpol
label var talkpol_change "Change in Days in next week talk politics (-=talk less; 0=no change; +=talk more)"

*Excited about voting in 2010
recode yal303 (998 999=.), gen(excite_2010)
label var excite_2010 "Excited about voting in 2010 (0=Not at all excited; 100=Very excited)"
recode yal447 (998 999=.), gen(excite_2010_post)
label var excite_2010_post "Excited about voting in 2010 (Post-Election) (0=Not at all excited; 100=Very excited)"
gen excite_2010_change = excite_2010_post-excite_2010 
label var excite_2010_change "Change in Excited about voting in 2010 (-=less excited; 0=no change; +=more excited)"

*Excited about voting in 2012
recode yal386 (998 999=.), gen(excite_2012)
label var excite_2012 "Excited about voting in 2012 (0=Not at all excited; 100=Very excited)"
recode yal492 (998 999=.), gen(excite_2012_post)
label var excite_2012_post "Excited about voting in 2012 (Post-Election) (0=Not at all excited; 100=Very excited)"
gen excite_2012_change = excite_2012_post-excite_2012 
label var excite_2012_change "Change in Excited about voting in 2012 (-=less excited; 0=no change; +=more excited)"

*Likely to vote in 2012
recode yal385 (998 999=.), gen(likely_2012)
label var likely_2012 "Likely to vote in 2012 (0=Not at all likely; 100=Very likely)"
recode yal491 (998 999=.), gen(likely_2012_post)
label var likely_2012_post "Likely to vote in 2012 (Post-Election) (0=Not at all likely; 100=Very likely)"
gen likely_2012_change = likely_2012_post-likely_2012 
label var likely_2012_change "Change in Likely to vote in 2012 (-=less likely; 0=no change; +=more likely)"

*Interpersonal trust
recode yal381 (998 999=.), gen(trust_int)
label var trust_int "Interpersonal trust (0=You can't be too careful; 100=Most people can be trusted)"
recode yal481 (998 999=.), gen(trust_int_post)
label var trust_int_post "Interpersonal trust (Post-Election) (0=You can't be too careful; 100=Most people can be trusted)"
gen trust_int_change = trust_int_post-trust_int
label var trust_int_change "Change in Interpersonal trust (-=less trusting; 0=no change; +=more trusting)"

*Government trust
recode yal382 (998 999=.), gen(trust_gov)
label var trust_gov "Trust in government (0=Never; 100=Always)"
recode yal482 (998 999=.), gen(trust_gov_post)
label var trust_gov_post "Trust in government (Post-Election) (0=Never; 100=Always)"
gen trust_gov_change = trust_gov_post-trust_gov
label var trust_gov_change "Change in Trust in government (-=less trusting; 0=no change; +=more trusting)"

*Approval ratings
 *Obama
recode cc308a (1=3) (2=2) (3=1) (4=0) (*=.), gen(app_obama)
label var app_obama "Approval: Obama (0=strongly disapprove; 3=strongly approve)"
recode yal471 (1=3) (2=2) (3=1) (4=0) (*=.), gen(app_obama_post)
label var app_obama_post "Approval: Obama (Post-Election) (0=strongly disapprove; 3=strongly approve)"
gen app_obama_change = app_obama_post-app_obama
label var app_obama_change "Change in Approval: Obama (-=lower approval; 0=no change; +=higher approval)"

 *Congress
recode cc308b (1=3) (2=2) (3=1) (4=0) (*=.), gen(app_congress)
label var app_congress "Approval: Congress (0=strongly disapprove; 3=strongly approve)"
recode yal472 (1=3) (2=2) (3=1) (4=0) (*=.), gen(app_congress_post)
label var app_congress_post "Approval: Congress (Post-Election) (0=strongly disapprove; 3=strongly approve)"
gen app_congress_change = app_congress_post-app_congress 
label var app_congress_change "Approval: Change in Congress (-=lower approval; 0=no change; +=higher approval)"

********************************
**** ATTRITION ANALYSIS (REPORTED IN FOOTNOTES 4, 5, & 10)
********************************

qui include "02_Sub_ConductReplicationAnalysis.do"

****************************
*** SET SAMPLE *************
****************************
drop std_conscientiousness_abs_change-dich_likely_2012_change

reg BF_conscientiousness_change BF_openness_change BF_agreeableness_change BF_stability_change BF_extraversion_change rwa_change nte_change nfc_change happy_change talkpol_change likely_2012_change trust_int_change trust_gov_change app_obama_change app_congress_change r_black r_hispanic r_otherrace gender age age2 income incomemis educ pid7 interest 
//sum BF_conscientiousness_change BF_openness_change BF_agreeableness_change BF_stability_change BF_extraversion_change rwa_change nte_change happy_change talkpol_change likely_2012_change trust_int_change trust_gov_change app_obama_change app_congress_change r_black r_hispanic r_otherrace gender age age2 income incomemis educ pid7 interest if e(sample)==0
keep if e(sample)

**************************
*** STANDARDIZE MEASURES
**************************
foreach i in BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion rwa nfc nte happy talkpol likely_2012 trust_int trust_gov app_obama app_congress{
local vname= subinstr("`i'", "BF_","",.)
sum `i'
local label : variable label `i'

local label=subinstr("`label'"," (0-1)","",.)
local label=subinstr("`label'","; 0-1","",.)
local label=subinstr("`label'"," (0=not at all happy; 3=very happy)","",.)
local label=subinstr("`label'"," (0-7)","",.)
local label=subinstr("`label'"," (0=Not at all likely; 100=Very likely)","",.)
local label=subinstr("`label'"," (0=You can't be too careful; 100=Most people can be trusted)","",.)
local label=subinstr("`label'"," (0=Never; 100=Always)","",.)
local label=subinstr("`label'"," (0=strongly disapprove; 3=strongly approve)","",.)

gen std_`vname'_abs_change=abs(`i'_change)/r(sd)
label var std_`vname'_abs_change "Absolute Change in `label' (standardized)"
gen std_`vname'_change=`i'_change/r(sd)
label var std_`vname'_change "Change in `label'"
gen std_`vname'=(`i'-r(mean))/r(sd)
label var std_`vname' "`label'"
gen std_`vname'_post=(`i'_post-r(mean))/r(sd)
label var std_`vname'_post "`label' (Post-Election; standardized)"
}

*** DICHOTOMIZE MEASURES ***
foreach i in conscientiousness openness agreeableness stability extraversion rwa nfc nte happy trust_int trust_gov app_obama app_congress talkpol likely_2012{
local label : variable label std_`i'
gen dich_`i'=std_`i'>0
gen dich_`i'_post=std_`i'_post>0
gen dich_`i'_change=dich_`i'_post-dich_`i'
label var dich_`i' "`label' (dichotomous)"
label var dich_`i'_post "`label' (Post-Election; dichotomous)"
label var dich_`i'_change "Change in `label' (dichotomous)"
}

***********************************
** SUMMARY STATS (NOT REPORTED)
***********************************
cap outsum r_white r_black r_hispanic r_otherrace gender age income incomemis educ religatt pid_democrat pid_republican ideol using "logs/summarystats.out", bracket replace

*********************************
** SUMMARY OF MEASURES AND EXPECTATIONS (TABLE 1)
*********************************
* In Text

*********************************
** CORRELATIONS (TABLE 2)
*********************************
corr std_conscientiousness std_openness std_agreeableness std_stability std_extraversion std_rwa std_nfc std_nte std_happy std_talkpol std_likely_2012 std_trust_int std_trust_gov std_app_obama std_app_congress

file open myfile using "logs/table2.csv", write replace 
file write myfile ",,(1),(2)" _n
file write myfile "Variable,Scale Source,Polychoric Correlation,Tetrachoric Correlation (dichotomous),% identical" _n
local shifts="Statistically significant mean shifts: "
qui count
local N=r(N)
*counter to indicate shift in scale type
local counter=0
local scales="Two 7-point scales; Three 2-point scales; One 3-point/one 2-point scale; One 4-point/one 3-point scale; 4-point scale; 100-point slider; 4-point scale; 7-point scale; 100-point slider"

foreach i in conscientiousness openness agreeableness stability extraversion rwa nfc nte happy trust_int trust_gov app_obama app_congress talkpol likely_2012{
local counter=`counter'+1
if (`counter'==1)|(`counter'==6)|(`counter'==7)|(`counter'==8)|(`counter'==9)|(`counter'==10)|(`counter'==12)|(`counter'==14)|(`counter'==15){
 gettoken scale scales : scales, parse(";") 
local scale_label="`scale'"
 gettoken scale scales : scales, parse(";") 
}
local label : variable label std_`i'
polychoric std_`i' std_`i'_post
local polychoric=r(rho)
tetrachoric dich_`i' dich_`i'_post
local dich_corr=r(rho)
count if std_`i'==std_`i'_post
local pct_move=r(N)/`N'
ttest std_`i'_change==0
if r(p)<.05{
 local p=round(r(p),.001)
 local val=round(r(mu_1),.001)
 local shifts="`shifts' `label' (`val', p=`p'); "
}
 file write myfile "`label',`scale_label',`polychoric',`dich_corr',`pct_move'" _n
}
 file write myfile "Values in column (1) are polychoric correlations between standardized pre- and post-election variables. Values in column (2) are tetrachoric correlations between dichotomized pre- and post-election variables. Values in column (3) are percentages of cases where respondents pre- and post-election wave measures were identical. `shifts'.,," _n
file close myfile

*************************
*** REGRESSIONS (TABLE 3)
*************************

foreach i in conscientiousness openness agreeableness stability extraversion rwa nfc nte happy trust_int trust_gov app_obama app_congress talkpol likely_2012{
reg std_`i'_change pid_democrat pid_republican, r
lincom pid_democrat-pid_republican 
local diff=r(estimate)
local diff_p=ttail(r(df),abs(r(estimate)/r(se)))*2
test pid_democrat pid_republican 
if "`i'"=="conscientiousness"{
outreg using "logs/table3_col1&2.out", se bracket rdec(3) 3aster replace adec(3) addstat("Joint Significance of PID",r(p),"Difference (Dem-Rep)",`diff',"Significance of Difference",`diff_p')
}
else{
outreg using "logs/table3_col1&2.out", se bracket rdec(3) 3aster append adec(3) addstat("Joint Significance of PID",r(p),"Difference (Dem-Rep)",`diff',"Significance of Difference",`diff_p')
}

reg std_`i'_change pid_democrat_wlean pid_republican_wlean, r
lincom pid_democrat_wlean-pid_republican_wlean
local diff=r(estimate)
local diff_p=ttail(r(df),abs(r(estimate)/r(se)))*2
test pid_democrat_wlean pid_republican_wlean 
if "`i'"=="conscientiousness"{
outreg using "logs/table3_col3&4.out", se bracket rdec(3) 3aster replace adec(3) addstat("Joint Significance of PID",r(p),"Difference (Dem-Rep)",`diff',"Significance of Difference",`diff_p')
}
else{
outreg using "logs/table3_col3&4.out", se bracket rdec(3) 3aster append adec(3) addstat("Joint Significance of PID",r(p),"Difference (Dem-Rep)",`diff',"Significance of Difference",`diff_p')
}

reg std_`i'_change pid7, r
test pid7
if "`i'"=="conscientiousness"{
outreg using "logs/table3_col5&6.out", se bracket rdec(3) 3aster replace adec(3) addstat("Significance of Party ID",r(p))

}
else{
outreg using "logs/table3_col5&6.out", se bracket rdec(3) 3aster append  adec(3) addstat("Significance of Party ID",r(p))
}
}

foreach i in conscientiousness openness agreeableness stability extraversion rwa nfc nte happy trust_int trust_gov app_obama app_congress talkpol likely_2012{
reg std_`i'_change pid7, r
}

*************************
*** PRE-POST TIME GAP (REPORTED IN FOOTNOTE 3)
*************************
**** PRE-POST TIME GAP
gen double time_gap= hours(v404-v401)/24
gen gap=round(time_gap)

foreach i in conscientiousness openness agreeableness stability extraversion rwa nfc nte happy trust_int trust_gov app_obama app_congress talkpol likely_2012{
gen `i'Xdays=std_`i'*time_gap
}

foreach i in conscientiousness openness agreeableness stability extraversion rwa nfc nte happy trust_int trust_gov app_obama app_congress talkpol likely_2012{
gen pre_interact=`i'Xdays
reg std_`i'_post std_`i' time_gap pre_interact, r
if "`i'"=="conscientiousness"{
outreg using "logs/footnote3.out", se bracket rdec(3) 3aster replace
}
else{
outreg using "logs/footnote3.out", se bracket rdec(3) 3aster append 
}
drop pre_interact
}

